@@ -29,7 +29,7 @@ function getYouTubeVideos() {
                         videoListModel.totalResults--;
                     }
                     else {
-                        videoListModel.append({ "playerUrl": "http://youtube.com/watch?v=" + res.id.$t, "id": res.id.$t,
+                        videoListModel.append({ "playerUrl": "http://youtube.com/watch?v=" + res.media$group.yt$videoid.$t, "id": res.id.$t,
                                               "videoId": res.media$group.yt$videoid.$t, "title": res.title.$t,
                                               "description": res.media$group.media$description.$t, "author": res.media$group.media$credit[0].$t,
                                               "likes": res.yt$rating ? res.yt$rating.numLikes : "0", "dislikes": res.yt$rating ? res.yt$rating.numDislikes : "0",
@@ -251,6 +251,7 @@ function getCurrentLiveStreams() {
 function createVideoObject(video) {
     var videoObject = {};
     videoObject["id"] = video.id;
+    videoObject["videoId"] = video.videoId;
     videoObject["playerUrl"] = video.playerUrl;
     videoObject["title"] = video.title;
     videoObject["duration"] = video.duration;
